@@ -1,7 +1,7 @@
 /*
  * libeio API header
  *
- * Copyright (c) 2007,2008,2009,2010,2011,2012,2015,2016,2017 Marc Alexander Lehmann <libeio@schmorp.de>
+ * Copyright (c) 2007,2008,2009,2010,2011,2012 Marc Alexander Lehmann <libeio@schmorp.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modifica-
@@ -171,21 +171,8 @@ enum
 enum
 {
   /* these MUST match the value in linux/falloc.h */
-  EIO_FALLOC_FL_KEEP_SIZE      = 0x01,
-  EIO_FALLOC_FL_PUNCH_HOLE     = 0x02,
-  EIO_FALLOC_FL_COLLAPSE_RANGE = 0x08,
-  EIO_FALLOC_FL_ZERO_RANGE     = 0x10,
-  EIO_FALLOC_FL_INSERT_RANGE   = 0x20,
-  EIO_FALLOC_FL_UNSHARE_RANGE  = 0x40
-};
-
-/* eio_rename flags */
-enum
-{
-  /* these MUST match the value in linux/fs.h */
-  EIO_RENAME_NOREPLACE = 1 << 0,
-  EIO_RENAME_EXCHANGE  = 1 << 1,
-  EIO_RENAME_WHITEOUT  = 1 << 2
+  EIO_FALLOC_FL_KEEP_SIZE  = 1,
+  EIO_FALLOC_FL_PUNCH_HOLE = 2
 };
 
 /* timestamps and differences - feel free to use double in your code directly */
@@ -198,7 +185,7 @@ enum
   EIO_WD_OPEN, EIO_WD_CLOSE,
 
   EIO_CLOSE, EIO_DUP2,
-  EIO_SEEK, EIO_READ, EIO_WRITE, EIO_FCNTL, EIO_IOCTL,
+  EIO_SEEK, EIO_READ, EIO_WRITE,
   EIO_READAHEAD, EIO_SENDFILE,
   EIO_FSTAT, EIO_FSTATVFS,
   EIO_FTRUNCATE, EIO_FUTIME, EIO_FCHMOD, EIO_FCHOWN,
@@ -222,7 +209,6 @@ enum
   EIO_UNLINK, EIO_RMDIR, EIO_MKDIR, EIO_RENAME,
   EIO_MKNOD,
   EIO_LINK, EIO_SYMLINK, EIO_READLINK,
-  EIO_SLURP, /* open + read + close */
 
   EIO_REQ_TYPE_NUM
 };
@@ -242,8 +228,7 @@ enum
 enum
 {
   EIO_MCL_CURRENT = 1,
-  EIO_MCL_FUTURE  = 2,
-  EIO_MCL_ONFAULT = 4
+  EIO_MCL_FUTURE  = 2
 };
 
 /* request priorities */
@@ -264,15 +249,15 @@ struct eio_req
   eio_wd wd;       /* all applicable requests: working directory of pathname, old name; wd_open: return wd */
 
   eio_ssize_t result;  /* result of syscall, e.g. result = read (... */
-  off_t offs;      /* read, write, truncate, readahead, sync_file_range, fallocate, slurp: file offset, mknod: dev_t */
-  size_t size;     /* read, write, readahead, sendfile, msync, mlock, sync_file_range, fallocate, slurp: length */
-  void *ptr1;      /* all applicable requests: pathname, old name, readdir: optional eio_dirents */
+  off_t offs;      /* read, write, truncate, readahead, sync_file_range, fallocate: file offset, mknod: dev_t */
+  size_t size;     /* read, write, readahead, sendfile, msync, mlock, sync_file_range, fallocate: length */
+  void *ptr1;      /* all applicable requests: pathname, old name; readdir: optional eio_dirents */
   void *ptr2;      /* all applicable requests: new name or memory buffer; readdir: name strings */
   eio_tstamp nv1;  /* utime, futime: atime; busy: sleep time */
   eio_tstamp nv2;  /* utime, futime: mtime */
 
   int int1;        /* all applicable requests: file descriptor; sendfile: output fd; open, msync, mlockall, readdir: flags */
-  long int2;       /* chown, fchown: uid; sendfile: input fd; open, chmod, mkdir, mknod: file mode, seek: whence, fcntl, ioctl: request, sync_file_range, fallocate, rename: flags */
+  long int2;       /* chown, fchown: uid; sendfile: input fd; open, chmod, mkdir, mknod: file mode, seek: whence, sync_file_range, fallocate: flags */
   long int3;       /* chown, fchown: gid; rename, link: working directory of new name */
   int errorno;     /* errno value on syscall return */
 
@@ -300,6 +285,7 @@ struct eio_req
 enum {
   EIO_FLAG_PTR1_FREE = 0x01, /* need to free(ptr1) */
   EIO_FLAG_PTR2_FREE = 0x02, /* need to free(ptr2) */
+  EIO_FLAG_GROUPADD  = 0x04  /* some request was added to the group */
 };
 
 /* undocumented/unsupported/private helper */
@@ -336,7 +322,6 @@ unsigned int eio_nthreads (void); /* number of worker threads in use currently *
 
 /*****************************************************************************/
 /* convenience wrappers */
-/* these do not expose advanced syscalls and directory fds */
 
 #ifndef EIO_NO_WRAPPERS
 eio_req *eio_wd_open   (const char *path, int pri, eio_cb cb, void *data); /* result=wd */
@@ -358,8 +343,6 @@ eio_req *eio_readahead (int fd, off_t offset, size_t length, int pri, eio_cb cb,
 eio_req *eio_seek      (int fd, off_t offset, int whence, int pri, eio_cb cb, void *data);
 eio_req *eio_read      (int fd, void *buf, size_t length, off_t offset, int pri, eio_cb cb, void *data);
 eio_req *eio_write     (int fd, void *buf, size_t length, off_t offset, int pri, eio_cb cb, void *data);
-eio_req *eio_fcntl     (int fd, int cmd, void *arg, int pri, eio_cb cb, void *data);
-eio_req *eio_ioctl     (int fd, unsigned long request, void *buf, int pri, eio_cb cb, void *data);
 eio_req *eio_fstat     (int fd, int pri, eio_cb cb, void *data); /* stat buffer=ptr2 allocated dynamically */
 eio_req *eio_fstatvfs  (int fd, int pri, eio_cb cb, void *data); /* stat buffer=ptr2 allocated dynamically */
 eio_req *eio_futime    (int fd, eio_tstamp atime, eio_tstamp mtime, int pri, eio_cb cb, void *data);
@@ -386,7 +369,6 @@ eio_req *eio_mknod     (const char *path, mode_t mode, dev_t dev, int pri, eio_c
 eio_req *eio_link      (const char *path, const char *new_path, int pri, eio_cb cb, void *data);
 eio_req *eio_symlink   (const char *path, const char *new_path, int pri, eio_cb cb, void *data);
 eio_req *eio_rename    (const char *path, const char *new_path, int pri, eio_cb cb, void *data);
-eio_req *eio_slurp     (const char *path, void *buf, size_t length, off_t offset, int pri, eio_cb cb, void *data);
 eio_req *eio_custom    (void (*execute)(eio_req *), int pri, eio_cb cb, void *data);
 #endif
 
@@ -421,7 +403,6 @@ void eio_cancel (eio_req *req);
 /* convenience functions */
 
 eio_ssize_t eio_sendfile_sync (int ofd, int ifd, off_t offset, size_t count);
-int eio_mlockall_sync (int flags);
 
 #ifdef __cplusplus
 }
